@@ -14,13 +14,33 @@ use uv_fs::write_atomic;
 use uv_redacted::DisplaySafeUrl;
 
 use crate::BaseClient;
-use crate::base_client::is_extended_transient_error;
+use crate::base_client::is_transient_network_error;
+use crate::error::ProblemDetails;
 use crate::{
     Error, ErrorKind,
     httpcache::{AfterResponse, BeforeRequest, CachePolicy, CachePolicyBuilder},
     rkyvutil::OwnedArchive,
 };
 
+/// Extract problem details from an HTTP response if it has the correct content type
+///
+/// Note: This consumes the response body, so it should only be called when there's an error status.
+async fn extract_problem_details(response: Response) -> Option<ProblemDetails> {
+    match response.bytes().await {
+        Ok(bytes) => match serde_json::from_slice(&bytes) {
+            Ok(details) => Some(details),
+            Err(err) => {
+                warn!("Failed to parse problem details: {err}");
+                None
+            }
+        },
+        Err(err) => {
+            warn!("Failed to read response body for problem details: {err}");
+            None
+        }
+    }
+}
+
 /// A trait the generalizes (de)serialization at a high level.
 ///
 /// The main purpose of this trait is to make the `CachedClient` work for
@@ -141,7 +161,7 @@ impl<CallbackError: std::error::Error + 'static> CachedClientError<CallbackError
         }
     }
 
-    fn error(&self) -> &dyn std::error::Error {
+    fn error(&self) -> &(dyn std::error::Error + 'static) {
         match self {
             Self::Client { err, .. } => err,
             Self::Callback { err, .. } => err,
@@ -452,7 +472,8 @@ impl CachedClient {
         .await
     }
 
-    #[instrument(name="read_and_parse_cache", skip_all, fields(file = %cache_entry.path().display()))]
+    #[instrument(name = "read_and_parse_cache", skip_all, fields(file = %cache_entry.path().display()
+    ))]
     async fn read_cache(cache_entry: &CacheEntry) -> Option<DataWithCachePolicy> {
         match DataWithCachePolicy::from_path_async(cache_entry.path()).await {
             Ok(data) => Some(data),
@@ -536,16 +557,36 @@ impl CachedClient {
         cached: DataWithCachePolicy,
         new_cache_policy_builder: CachePolicyBuilder,
     ) -> Result<CachedResponse, Error> {
-        let url = DisplaySafeUrl::from(req.url().clone());
+        let url = DisplaySafeUrl::from_url(req.url().clone());
         debug!("Sending revalidation request for: {url}");
         let mut response = self
             .0
             .execute(req)
             .instrument(info_span!("revalidation_request", url = url.as_str()))
             .await
-            .map_err(|err| ErrorKind::from_reqwest_middleware(url.clone(), err))?
-            .error_for_status()
-            .map_err(|err| ErrorKind::from_reqwest(url.clone(), err))?;
+            .map_err(|err| ErrorKind::from_reqwest_middleware(url.clone(), err))?;
+
+        // Check for HTTP error status and extract problem details if available
+        if let Err(status_error) = response.error_for_status_ref() {
+            // Clone the response to extract problem details before the error consumes it
+            let problem_details = if response
+                .headers()
+                .get("content-type")
+                .and_then(|ct| ct.to_str().ok())
+                .map(|ct| ct == "application/problem+json")
+                .unwrap_or(false)
+            {
+                extract_problem_details(response).await
+            } else {
+                None
+            };
+            return Err(ErrorKind::from_reqwest_with_problem_details(
+                url.clone(),
+                status_error,
+                problem_details,
+            )
+            .into());
+        }
 
         // If the user set a custom `Cache-Control` header, override it.
         if let CacheControl::Override(header) = cache_control {
@@ -586,7 +627,7 @@ impl CachedClient {
         req: Request,
         cache_control: CacheControl<'_>,
     ) -> Result<(Response, Option<Box<CachePolicy>>), Error> {
-        let url = DisplaySafeUrl::from(req.url().clone());
+        let url = DisplaySafeUrl::from_url(req.url().clone());
         trace!("Sending fresh {} request for {}", req.method(), url);
         let cache_policy_builder = CachePolicyBuilder::new(&req);
         let mut response = self
@@ -610,9 +651,25 @@ impl CachedClient {
             .map(|retries| retries.value());
 
         if let Err(status_error) = response.error_for_status_ref() {
+            let problem_details = if response
+                .headers()
+                .get("content-type")
+                .and_then(|ct| ct.to_str().ok())
+                .map(|ct| ct.starts_with("application/problem+json"))
+                .unwrap_or(false)
+            {
+                extract_problem_details(response).await
+            } else {
+                None
+            };
             return Err(CachedClientError::<Error>::Client {
                 retries: retry_count,
-                err: ErrorKind::from_reqwest(url, status_error).into(),
+                err: ErrorKind::from_reqwest_with_problem_details(
+                    url,
+                    status_error,
+                    problem_details,
+                )
+                .into(),
             }
             .into());
         }
@@ -680,19 +737,21 @@ impl CachedClient {
 
             if result
                 .as_ref()
-                .is_err_and(|err| is_extended_transient_error(err.error()))
+                .is_err_and(|err| is_transient_network_error(err.error()))
             {
                 // If middleware already retried, consider that in our retry budget
                 let total_retries = past_retries + middleware_retries;
                 let retry_decision = retry_policy.should_retry(start_time, total_retries);
                 if let reqwest_retry::RetryDecision::Retry { execute_after } = retry_decision {
-                    debug!(
-                        "Transient failure while handling response from {}; retrying...",
-                        req.url(),
-                    );
                     let duration = execute_after
                         .duration_since(SystemTime::now())
                         .unwrap_or_else(|_| Duration::default());
+
+                    debug!(
+                        "Transient failure while handling response from {}; retrying after {:.1}s...",
+                        req.url(),
+                        duration.as_secs_f32(),
+                    );
                     tokio::time::sleep(duration).await;
                     past_retries += 1;
                     continue;
@@ -739,18 +798,19 @@ impl CachedClient {
             if result
                 .as_ref()
                 .err()
-                .is_some_and(|err| is_extended_transient_error(err.error()))
+                .is_some_and(|err| is_transient_network_error(err.error()))
             {
                 let total_retries = past_retries + middleware_retries;
                 let retry_decision = retry_policy.should_retry(start_time, total_retries);
                 if let reqwest_retry::RetryDecision::Retry { execute_after } = retry_decision {
-                    debug!(
-                        "Transient failure while handling response from {}; retrying...",
-                        req.url(),
-                    );
                     let duration = execute_after
                         .duration_since(SystemTime::now())
                         .unwrap_or_else(|_| Duration::default());
+                    debug!(
+                        "Transient failure while handling response from {}; retrying after {}s...",
+                        req.url(),
+                        duration.as_secs(),
+                    );
                     tokio::time::sleep(duration).await;
                     past_retries += 1;
                     continue;
