@@ -21,11 +21,11 @@ async fn remote_metadata_with_and_without_cache() -> Result<()> {
         let filename = WheelFilename::from_str(url.rsplit_once('/').unwrap().1)?;
         let dist = BuiltDist::DirectUrl(DirectUrlBuiltDist {
             filename,
-            location: Box::new(DisplaySafeUrl::parse(url).unwrap()),
-            url: VerbatimUrl::from_str(url).unwrap(),
+            location: Box::new(DisplaySafeUrl::parse(url)?),
+            url: VerbatimUrl::from_str(url)?,
         });
         let capabilities = IndexCapabilities::default();
-        let metadata = client.wheel_metadata(&dist, &capabilities).await.unwrap();
+        let metadata = client.wheel_metadata(&dist, &capabilities).await?;
         assert_eq!(metadata.version.to_string(), "4.66.1");
     }
 
